---
title: Howto BTRFS
categories: tips system
...

* site officiel : <https://btrfs.wiki.kernel.org/index.php/Main_Page>

[Btrfs (B-tree file system, prononcé ButterFS)](https://btrfs.wiki.kernel.org/index.php/Main_Page) est un système de fichiers des années 2010 fondé sur le Copy-On-Write (copie sur écriture en français) sous licence GNU GPL, développé conjointement par Oracle, Red Hat, Fujitsu, Intel, SUSE, STRATO AG (en) et autres. En 2012, alors qu'il n'était pas encore considéré comme tout-à-fait stable, un effort intense de développement et de test est fourni par la communauté afin de faire de Btrfs le successeur de ext4 et ext3, systèmes de fichiers habituels des distributions Linux. OpenSuse 13.2 propose dès son lancement Btrfs par défaut pour la partition racine afin d'assurer la sécurité et laisse le choix entre ext4 et XFS (plus rapide) pour /home. 

Btrfs offre les fonctionnalités suivantes absentes d'autres systèmes de fichiers :

- Instantané (snapshots)
- somme de contrôle

Ces caractéristiques sont importantes pour les systèmes Linux, serveurs comme postes clients, car les tailles de stockage comme les configurations tendent à augmenter et à se complexifier. 

## Installation

~~~{.bash}
# apt install btrfs-tools
~~~

## Utilisation de base

Formater une partition

~~~{.bash}
# mkfs.btrfs /dev/sda9
~~~

Montage persistent

~~~{.bash}
# echo "/dev/sda9 /backup         btrfs    defaults        0       0" >> /etc/fstab
# mount /backup
~~~

Augmenter la taille d'une partition montée

~~~{.bash}
# btrfs filesystem resize +42g /pointdemontage
~~~

Réduire la taille d'une partition montée

~~~{.bash}
# btrfs filesystem resize -42g /pointdemontage
~~~

Création de subvolumes

~~~{.bash}
# btrfs subvolume create /backup/aaa
# btrfs subvolume create /backup/bbb
~~~

Liste des subvolumes disponibles

~~~{.bash}
# btrfs subvolume list /backup/
~~~

Créer un snapshot

~~~{.bash}
# btrfs subvolume snapshot /backup/aaa /backup/bbb/snapshot1
~~~

Supprimer un subvolume (et snapshot)

~~~{.bash}
# btrfs subvolume delete /bbb/bbb/snapshot1
~~~

Lister les propriétés d'un subvolume

~~~{.bash}
# btrfs property list -ts /path/to/subvolume
~~~

Passer un subvolume en RW

~~~{.bash}
# btrfs property set -ts /path/to/subvolume ro false
~~~

Passer un subvolume en RO

~~~{.bash}
# btrfs property set -ts /path/to/subvolume ro true
~~~

### Manipulations d'un subvolume

Pour déplacer un subvolume, il faut créer un snapshot en read-only du subvolume que l'on souhaite déplacer/renommer puis supprimer l'original. 

~~~{.bash}
# btrfs sub snap -r /path/to/subvolume /path/to/snapshot
# btrfs subvolume delete /path/to/subvolume
~~~

On passera ensuite le volume en read/write

~~~{.bash}
# btrfs property set -ts /path/to/snapshot ro false
~~~

### Envoyer un subvolume

Pour transférer un subvolume vers un autre serveur, il faut créer un snapshot en read-only du subvolume en question.

~~~{.bash}
# btrfs sub snap -r /path/to/subvolume /path/to/snapshot-RO
~~~

On peut ensuite envoyer le volume via SSH

~~~{.bash}
# btrfs send /path/to/snapshot-RO | ssh root@192.0.2.1 "btrfs receive /path/to/remote-snapshot"
~~~

## Maintenance

Vérifier l'intégrité d'un subvolume

~~~{.bash}
# btrfs scrub start /backup/
# btrfs scrub status /backup/
~~~

Vérification plus poussé sur une partition non montée

~~~{.bash}
# btrfs check -p /dev/sda9
~~~

Voir si la partition a présenté des erreurs

~~~{.bash}
# btrfs dev stats /backup
~~~

## Liens

* [Wikipédia BTRFS](https://fr.wikipedia.org/wiki/Btrfs)
* [Debian BTRFS](https://wiki.debian.org/Btrfs)